# volume and mute: An Add-on for nvda that does <Insert thing here>

#Copyright (C) 2016 Derek Riemer

#This file is covered by the GNU General Public License.
#See the file COPYING for more details.

"""volumeAndMute:
A global plugin 
"""

import os
import addonHandler
import globalPluginHandler
import nvwave
import api
import wx, gui
#We need to initialize translation and localization support:
addonHandler.initTranslation()

class MuteNVDADialog(wx.Dialog):
	class MultiInstanceError(RuntimeError): pass
	#Translators: Title for a dialog to mute the computer.
	title = _("Mute the computer?")
	_hasInstance=False
	def __new__(cls, *args, **kwargs):
		if MuteNVDADialog._hasInstance:
			raise MuteNVDADialog.MultiInstanceError("Only one instance of MuteNVDADialog can exist at a time")
		obj = super(MuteNVDADialog, cls).__new__(cls, *args, **kwargs)
		MuteNVDADialog._hasInstance=True
		return obj

	def __init__(self, parent, gesture, *args, **kwargs):
		super(MuteNVDADialog, self).__init__(parent, *args, **kwargs)
		self.gesture = gesture
		mainSizer = wx.BoxSizer(wx.VERTICAL)
		textSizer = wx.BoxSizer(wx.VERTICAL)
		#Translators: Text to describe what will happen if the computer is muted.
		textSizer.Add(wx.StaticText(self, wx.NewId(), _("""You are about to mute the computer.
Doing this will make the computer scilent, but will also make the computer useless to a blind user. An assistive technology called NVDA is running on this computer which allows the blind to get audio feedback when navigating the computer. 
Are you sure you want to mute the computer? If you are a sighted person who is using this computer, and you are muting this computer because it is currently talking, press the "Just Stop Talking" button. Otherwise, press "Mute" to mute the computer, or "Do not mute" to leave the computer unmuted.""")))
		mainSizer.Add(textSizer)
		buttonSizer = wx.BoxSizer(wx.HORIZONTAL)
		buttonSizer.AddSpacer(100) 
		stopTalking = wx.Button(self, label=_("&Just stop talking"))
		buttonSizer.Add(stopTalking)
		mute = wx.Button(self, label=_("&Mute"))
		buttonSizer.Add(mute)
		noMute = wx.Button(self, label=_("&Do not mute"))
		buttonSizer.Add(noMute)
		mainSizer.Add(buttonSizer,border=20,flag=wx.LEFT|wx.RIGHT|wx.BOTTOM)
		mainSizer.Fit(self)
		self.SetSizer(mainSizer)
		stopTalking.Bind(wx.EVT_BUTTON,self.onStopTalking)
		mute.Bind(wx.EVT_BUTTON,self.onMute)
		noMute.Bind(wx.EVT_BUTTON,self.onNoMute)
		self.Center(wx.BOTH | wx.CENTER_ON_SCREEN)

	def __del__(self):
		MuteNVDADialog._hasInstance=False

	def onStopTalking(self, evt):
		wx.GetApp().ExitMainLoop()

	def onMute(self, evt):
		self.gesture.send()
		self.Destroy()

	def onNoMute(self, gesture):
		self.Destroy()


class GlobalPlugin(globalPluginHandler.GlobalPlugin):
	def script_volume(self, gesture):
		gesture.send()
		nvwave.playWaveFile(os.path.join(os.path.dirname(__file__), "blurp.wav"))

	def script_mute(self, gesture):
		try:
			size = api.getDesktopObject().location
			dlg = MuteNVDADialog(gui.mainFrame, gesture, size=(size[2]-500, size[3]-200))
		except MuteNVDADialog.MultiInstanceError:
			return
		gui.mainFrame.prePopup()
		dlg.Show()
		gui.mainFrame.postPopup()
	__gestures = {
		"kb:volumeDown" : "volume",
		"kb:volumeUp" : "volume",
		"kb:volumeMute" : "mute",
	}
